.. image:: https://travis-ci.org/joommf/discretisedfield.svg?branch=master
  :target: https://travis-ci.org/joommf/discretisedfield
  :align: left

.. image:: https://codecov.io/gh/joommf/discretisedfield/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/joommf/discretisedfield
  :align: right
  
.. image:: https://readthedocs.org/projects/discretisedfield/badge/?version=latest
  :target: http://discretisedfield.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

.. image:: https://badge.fury.io/py/discretisedfield.svg
   :target: https://badge.fury.io/py/discretisedfield

This module is a Python package that provides:

- Analysis of finite difference and finite element fields, such as sampling, averaging, plotting, etc.

discretisedfield is a member of JOOMMF_ project - a part of OpenDreamKit_
Horizon 2020 European Research Infrastructure project

.. _JOOMMF:
  http://joommf.github.io
 
.. _OpenDreamKit:
  http://opendreamkit.org/

Authors: Marijan Beg, Ryan Pepper, Hans Fangohr
